This crate contains kube-rs compatible bindings for Kubernetes custom resources for the servicemesh.cisco.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
servicemesh.cisco.com/v1alpha1
IstioControlPlaneIstioMeshIstioMeshGatewayPeerIstioControlPlane